package ozstd

  1. Overview
  2. Docs

Module Decompressor.StateSource

A decompression stream state for feeding bytes during streaming decompression.

Sourcetype t
Sourceval make : ?out_buf:Bstr.t -> ?stream:Stream.t -> unit -> t

make ?out_buf ?stream stream

Creates a decompression stream state from an existing decompression stream. If out_buf is omitted, a default output buffer is allocated.

Sourceval create : ?dictionary:Dictionary.t -> ?size_limit:int -> unit -> t

create ?dictionary ?size_limit ()

Creates a new decompression stream.

Compression

feed state slice

Decompresses slice and provides the decompressed data as an output slice.

  • raises Already_closed