package ozstd

  1. Overview
  2. Docs

Module Ozstd.Zstd_errorSource

Sourcetype zstd_error_code =
  1. | No_error
  2. | Generic
  3. | Prefix_unknown
  4. | Version_unsupported
  5. | Frame_parameter_unsupported
  6. | Frame_parameter_window_too_large
  7. | Corruption_detected
  8. | Checksum_wrong
  9. | Literals_header_wrong
  10. | Dictionary_corrupted
  11. | Dictionary_wrong
  12. | Dictionary_creation_failed
  13. | Parameter_unsupported
  14. | Parameter_combination_unsupported
  15. | Parameter_out_of_bound
  16. | Table_log_too_large
  17. | Max_symbol_value_too_large
  18. | Max_symbol_value_too_small
  19. | Cannot_produce_uncompressed_block
  20. | Stability_condition_not_respected
  21. | Stage_wrong
  22. | Init_missing
  23. | Memory_allocation
  24. | Work_space_too_small
  25. | Dst_size_too_small
  26. | Src_size_wrong
  27. | Dst_buffer_null
  28. | No_forward_progress_dest_full
  29. | No_forward_progress_input_empty
  30. | Frame_index_too_large
  31. | Seekable_io
  32. | Dst_buffer_wrong
  33. | Src_buffer_wrong
  34. | Sequence_producer_failed
  35. | External_sequences_invalid
  36. | Max_code
Sourceexception Zstd_error of zstd_error_code * string * string

Zstd_error code func message is raised when the underlying Zstandard C library reports an error, with message the error reported by zstd.