Page
Library
Module
Module type
Parameter
Class
Class type
Compressor.StreamSourceThe compression stream module for incremental compression.
Raised when trying to compress a closed stream.
create ?dictionary ?level ()
Creates a new compression stream.
of_context context
Creates a compression stream from the existing compression context.
val compress :
in_slice:Slice_bstr.t ->
out_slice:Slice_bstr.t ->
t ->
[< `Continue | `End | `Flush ] ->
remaining:int * consumed:int * compressed:intcompress ~in_buffer ~out_buffer stream mode
Compresses bytes from in_buffer into out_buffer buffer.
The mode argument controls the flushing behavior of the stream.
in_size () returns the recommended size for the input compression buffer.
out_size () returns the recommended size for the output compression buffer.