Page
Library
Module
Module type
Parameter
Class
Class type
Ozstd.DecompressorSourceZstandard decompression module.
The module offers both one-shot and streaming APIs for decompressing data.
decompress_bigstring ?context ?dictionary bigstring
Decompresses bigstring and returns the uncompressed data as a new bigstring.
decompress_string ?context ?dictionary string
Decompresses string and returns the uncompressed data as a new string.
val decompress_channel :
?dictionary:Dictionary.t ->
?size_limit:int ->
in_channel ->
out_channel ->
unitdecompress_channel ic oc
Decompresses data from ic channel to oc channel.
val decompress_bigstring_into :
?context:Context.t ->
?dictionary:Dictionary.t ->
Bstr.t ->
Bstr.t ->
intcompress_bigstring_into ?context ?dictionary src dst
Decompresses src bigstring into dst bigstring buffer.
val decompress_string_into_bytes :
?context:Context.t ->
?dictionary:Dictionary.t ->
string ->
bytes ->
intcompress_bigstring_into ?context ?dictionary src dst
Decompresses src string into dst bytes buffer.